@@ -2,7 +2,7 @@ __author__ = 'Altertech, https://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2019 Altertech'
 __license__ = 'MIT'
 
-__version__ = '0.4.20'
+__version__ = '0.4.24'
 
 from sqlalchemy.exc import IntegrityError
 from cachetools import TTLCache
@@ -2257,6 +2257,8 @@ def account_balance(account=None,
         raise ValueError('Account and type can not be specified together')
     elif not account and not tp:
         tp = [k for k in ACCOUNT_TYPE_IDS if ACCOUNT_TYPE_IDS[k] <= 1000]
+    elif tp and '|' in tp:
+        tp = [x.strip() for x in tp.split('|')]
     if _grafana:
         if isinstance(date, int):
             date = date / 1000
@@ -2326,6 +2328,7 @@ def asset_rate_range(start,
     dt = parse_date(start, return_timestamp=False)
     end_date = parse_date(
         end, return_timestamp=False) if end else datetime.datetime.now()
+    end_date += datetime.timedelta(days=1)
     delta = datetime.timedelta(days=step)
     last_record = False
     while dt < end_date or not last_record:
@@ -2370,6 +2373,8 @@ def account_balance_range(start,
         raise ValueError('Account and type can not be specified together')
     elif not account and not tp:
         tp = [k for k in ACCOUNT_TYPE_IDS if ACCOUNT_TYPE_IDS[k] <= 1000]
+    elif tp and '|' in tp:
+        tp = [x.strip() for x in tp.split('|')]
     if _grafana:
         if isinstance(start, int):
             start = start / 1000
@@ -2382,6 +2387,7 @@ def account_balance_range(start,
     end_date = parse_date(
         end, return_timestamp=False) if end else datetime.datetime.now()
     delta = datetime.timedelta(days=step)
+    end_date += datetime.timedelta(days=1)
     last_record = False
     while dt < end_date or not last_record:
         if dt == end_date:
